@@ -93,7 +93,8 @@ typedef enum {
     ASPECT_4X3,
     ASPECT_16X9,
     ASPECT_16X10,
-    ASPECT_WINDOW
+    ASPECT_WINDOW,
+    ASPECT_ANAMORPHIC           // 2.39:1
 } GmtkMediaPlayerAspectRatio;
 
 typedef enum {
@@ -207,14 +208,17 @@ typedef enum {
     COMMAND_SWITCH_AUDIO,
     COMMAND_FRAME_STEP,
     COMMAND_SUBTITLE_SELECT,
-    COMMAND_SWITCH_FRAME_DROP
+    COMMAND_SWITCH_FRAME_DROP,
+    COMMAND_SUBTITLE_STEP_FORWARD,
+    COMMAND_SUBTITLE_STEP_BACKWARD
 } GmtkMediaPlayerCommand;
 
 typedef enum {
     EVENT_TYPE_INT,
     EVENT_TYPE_DOUBLE,
     EVENT_TYPE_BOOLEAN,
-    EVENT_TYPE_ALLOCATION
+    EVENT_TYPE_ALLOCATION,
+    EVENT_TYPE_STRING
 } GmtkMediaPlayerEventType;
 
 typedef struct _GmtkMediaPlayer GmtkMediaPlayer;
@@ -244,6 +248,7 @@ typedef struct _GmtkMediaPlayerEvent {
     gdouble event_data_double;
     gboolean event_data_boolean;
     GtkAllocation *event_allocation;
+    gchar *event_data_string;
 } GmtkMediaPlayerEvent;
 
 struct _GmtkMediaPlayer {
@@ -386,7 +391,11 @@ struct _GmtkMediaPlayer {
 
     GdkColor *default_background;
 
+    gboolean has_metadata;
+    gdouble speed;
+
     gboolean disposed;
+    GMutex *player_lock;
 };
 
 struct _GmtkMediaPlayerClass {
@@ -400,6 +409,7 @@ struct _GmtkMediaPlayerClass {
     void (*audio_tracks_changed) (GmtkMediaPlayer * player);
     void (*restart_shutdown_complete) (GmtkMediaPlayer * player);
     void (*restart_complete) (GmtkMediaPlayer * player);
+    void (*error_message) (GmtkMediaPlayer * player);
 };
 
 GType gmtk_media_player_get_type(void);
@@ -409,7 +419,7 @@ void gmtk_media_player_set_uri(GmtkMediaPlayer * player, const gchar * uri);
 const gchar *gmtk_media_player_get_uri(GmtkMediaPlayer * player);
 
 void gmtk_media_player_set_state(GmtkMediaPlayer * player, const GmtkMediaPlayerMediaState new_state);
-GmtkMediaPlayerMediaState gmtk_media_player_get_state(GmtkMediaPlayer * player);
+GmtkMediaPlayerMediaState gmtk_media_player_get_media_state(GmtkMediaPlayer * player);
 
 void gmtk_media_player_set_attribute_boolean(GmtkMediaPlayer * player,
                                              GmtkMediaPlayerMediaAttributes attribute, gboolean value);
@@ -451,6 +461,7 @@ void gmtk_media_player_send_command(GmtkMediaPlayer * player, GmtkMediaPlayerCom
 
 void gmtk_media_player_set_aspect(GmtkMediaPlayer * player, GmtkMediaPlayerAspectRatio aspect);
 GmtkMediaPlayerAspectRatio gmtk_media_player_get_aspect(GmtkMediaPlayer * player);
+const gchar *gmtk_media_state_to_string(const GmtkMediaPlayerMediaState media_state);
 
 
 G_END_DECLS
